@@ -25,6 +25,7 @@
 #include <KDBusService>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <KWindowSystem>
 
 #include <QDebug>
 #include <QPixmap>
@@ -39,7 +40,6 @@
 
 static const char description[] = I18N_NOOP("VNC-compatible server to share "
                                   "desktops");
-
 static bool checkX11Capabilities()
 {
     int bp1, bp2, majorv, minorv;
@@ -57,7 +57,6 @@ static bool checkX11Capabilities()
     return true;
 }
 
-
 static void checkOldX11PluginConfig() {
     if (KrfbConfig::preferredFrameBufferPlugin() == QStringLiteral("x11")) {
         qDebug() << "Detected deprecated configuration: preferredFrameBufferPlugin = x11";
@@ -71,6 +70,21 @@ static void checkOldX11PluginConfig() {
     }
 }
 
+static void checkWaylandPluginConfig()
+{
+    if (KrfbConfig::preferredFrameBufferPlugin() != QStringLiteral("pw")) {
+        qWarning() << "Wayland: Detected invalid configuration: "
+                    "preferredFrameBufferPlugin is not pipewire: "
+                   << KrfbConfig::preferredFrameBufferPlugin();
+        KConfigSkeletonItem *config_item = KrfbConfig::self()->findItem(
+                    QStringLiteral("preferredFrameBufferPlugin"));
+        if (config_item) {
+            config_item->setProperty(QStringLiteral("pw"));
+            KrfbConfig::self()->save();
+            qDebug() << "Wayland: Fixed preferredFrameBufferPlugin to \"pw\".";
+        }
+    }
+}
 
 int main(int argc, char *argv[])
 {
@@ -121,13 +135,24 @@ int main(int argc, char *argv[])
 
     app.setQuitOnLastWindowClosed(false);
 
-    if (!checkX11Capabilities()) {
+    if (KWindowSystem::isPlatformX11()) {
+        if (!checkX11Capabilities()) {
+            return 1;
+        }
+
+        // upgrade the configuration
+        checkOldX11PluginConfig();
+    } else if (KWindowSystem::isPlatformWayland()) {
+        // check that default plugin in Wayland is PipeWire
+        checkWaylandPluginConfig();
+    } else {
+        KMessageBox::error(nullptr,
+                           i18n("Desktop Sharing is not running under an X11 Server or Wayland.\n"
+                                "Other display servers are currently not supported."),
+                           i18n("Desktop Sharing Error"));
         return 1;
     }
 
-    // upgrade the configuration
-    checkOldX11PluginConfig();
-
     //init the core
     InvitationsRfbServer::init();
 
