@@ -34,6 +34,7 @@
 #include <QVector>
 #include <QSet>
 #include <QNetworkInterface>
+#include <QHostInfo>
 
 
 class TCP: public QWidget, public Ui::TCP
@@ -57,7 +58,7 @@ public:
         vboxLayout->addWidget(walletWarning);
 
         // show warning when "noWallet" checkbox is checked
-        QObject::connect(kcfg_noWallet, &QCheckBox::toggled, [this](bool checked){
+        QObject::connect(kcfg_noWallet, &QCheckBox::toggled, this, [this] (bool checked) {
             walletWarning->setVisible(checked);
         });
     }
@@ -141,10 +142,14 @@ MainWindow::MainWindow(QWidget *parent)
             continue;
 
         if(interface.flags() & QNetworkInterface::IsRunning &&
-                !interface.addressEntries().isEmpty())
-            m_ui.addressDisplayLabel->setText(QStringLiteral("%1 : %2")
-                    .arg(interface.addressEntries().first().ip().toString())
-                    .arg(port));
+                !interface.addressEntries().isEmpty()) {
+            const QString hostName = QHostInfo::localHostName();
+            const QString ipAddress = interface.addressEntries().constFirst().ip().toString();
+            const QString addressLabelText = hostName.isEmpty()
+                ? QStringLiteral("%1 : %2").arg(ipAddress).arg(port)
+                : QStringLiteral("%1 (%2) : %3").arg(hostName, ipAddress).arg(port);
+            m_ui.addressDisplayLabel->setText(addressLabelText);
+        }
     }
 
     //Figure out the password
@@ -256,7 +261,7 @@ void MainWindow::showConfiguration()
     dialog->addPage(new Security, i18n("Security"), QStringLiteral("security-high"));
     dialog->addPage(new ConfigFramebuffer, i18n("Screen capture"), QStringLiteral("video-display"));
     dialog->show();
-    connect(dialog, &KConfigDialog::settingsChanged, [this] () {
+    connect(dialog, &KConfigDialog::settingsChanged, this, [this] () {
         // check if framebuffer plugin config has changed
         if (s_prevFramebufferPlugin != KrfbConfig::preferredFrameBufferPlugin()) {
             KMessageBox::information(this, i18n("To apply framebuffer plugin setting, "
