@@ -21,6 +21,7 @@
 #define RFBSERVERMANAGER_H
 
 #include "rfb.h"
+#include "framebuffer.h"
 #include <QObject>
 
 class RfbClient;
@@ -33,12 +34,14 @@ class RfbServerManager : public QObject
 public:
     static RfbServerManager *instance();
 
+    QSharedPointer<FrameBuffer> framebuffer() const;
 Q_SIGNALS:
     void clientConnected(RfbClient *cc);
     void clientDisconnected(RfbClient *cc);
 
 private Q_SLOTS:
     void init();
+    void updateFrameBuffer();
     void updateScreens();
     void cleanup();
 
